==> openGion6.0.0.3_dev.zip: uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_INDEX_MYSQL.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

/**
 * TableFilter_INDEX_MYSQL は、TableUpda インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。とくに、MySQL用のインデックス作成スクリプトを作成します。
 *
 * ここでは、テーブル一覧の検索結果より、GF07 のインデックスカラム定義テーブルから
 * 必要な情報を取得し、テーブル作成スクリプトを作成します。
 * 出力ファイルは、テーブル名＋"I.sql" という命名規則で作成します。
 * 検索では、(SYSTEM_ID,TBLSYU,TABLE_NAME,NAME_JA,TABLESPACE_NAME,INITIAL_EXTENT,NEXT_EXTENT,COMMENTS)
 * の項目を取得する必要があります。
 *
 * @og.rev 4.0.0.0 (2005/08/31) 新規作成
 *
 * @version  0.9.0  2000/10/17
 * @author   Kazuhiko Hasegawa
 * @since    JDK1.1,
 */
public class TableFilter_INDEX_MYSQL extends TableFilter_INDEX {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.6.9.2 (2013/10/18)" ;

	/**
	 * 定義の最後の部分の処理を実行します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	定義の最後の部分
	 */
	@Override
	protected String makeEndLine( final int[] clmNo,final String[] data ) {
		return isXml ? EXEC_END_TAG : ";" ;
	}

	/**
	 * インデックス削除の構文を、作成します。
	 *
	 * @og.rev 5.6.9.2 (2013/10/18) 新規作成
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	作成された１行分の文字列
	 */
	@Override
	protected String makeDropLine( final int[] clmNo,final String[] data ) {
		String tableName = data[clmNo[TABLE_NAME]];
		String indexName = data[clmNo[INDEX_NAME]];
	//	String idxtype   = data[clmNo[INDTYPE]];

		StringBuilder buf = new StringBuilder();

		buf.append( CR );		// 先頭に、改行を入れておきます。
		if( isXml ) { buf.append( EXEC_START_TAG ).append( CR ); }

		// 0:プライマリキー , 1:ユニークキー
	//	if( "0".equals( idxtype ) || "1".equals( idxtype ) ) {
			buf.append( "ALTER TABLE " ).append( tableName ).append( " DROP INDEX " );
			buf.append( indexName );
	//	}
		// 5.6.9.2 (2013/10/18) INDTYPE で、その他ではなく、2:通常 で判断する。
	//	else if( "2".equals( idxtype ) ) {	// 2:通常
	//		buf.append( "DROP INDEX " ).append( indexName ).append( " ON " ).append( tableName );
	//	}
	//  一連の処理で、makeLineList ですでにエラーが出ているハズなので、ここでは出しません。
	//	else {
	//		String errMsg = "INDTYPE が、0,1,2 以外の値が使われています。INDTYPE=[" + idxtype + "]"
	//						+ " TABLE_NAME=[" + tableName + "] INDEX_NAME=[" + indexName + "]" ;
	//		System.out.println( errMsg );
	//	}

		if( isXml )	{ buf.append( CR ).append( EXEC_END_TAG ); }
		else		{ buf.append( ";" ); }

		return buf.toString();
	}

	/**
	 * インデックスを作成するための文字列を返します。
	 * 但し、唯一、MySQLの場合、500バイト以上のカラムについては、TEXTで定義しており、
	 * この場合、インデックス化するバイト数(最大255)を指定する必要があります。
	 * このケースに対応するため、カラム名とバイト数を元に判定し、部分インデックスを
	 * 作成するための文字列を作成します。
	 *
	 * @og.rev 5.1.1.2 (2009/12/10)
	 *
	 * @param	clm		カラム名
	 * @param	useLen	カラムのバイト数
	 *
	 * @return	インデックスカラムの文字列
	 */
	@Override
	protected String makeIndexClmStr( final String clm, final String useLen ) {
		int useLength = 0;
		if( useLen != null && useLen.length() > 0 ) {
			useLength = Integer.valueOf( useLen );
		}
		return useLength > TableFilter_TABLE_MYSQL.CLM_MAX_SIZE ? clm + "(255)" : clm ;
	}
}

==> openGion6.1.0.0_dev.zip: uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_INDEX_MYSQL.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

/**
 * TableFilter_INDEX_MYSQL は、TableUpda インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。とくに、MySQL用のインデックス作成スクリプトを作成します。
 *
 * ここでは、テーブル一覧の検索結果より、GF07 のインデックスカラム定義テーブルから
 * 必要な情報を取得し、テーブル作成スクリプトを作成します。
 * 出力ファイルは、テーブル名＋"I.sql" という命名規則で作成します。
 * 検索では、(SYSTEM_ID,TBLSYU,TABLE_NAME,TABLE_LABEL,INDEX_NAME,NAME_JA,INDTYPE,TABLESPACE_NAME,INITIAL_EXTENT)
 * の項目を取得する必要があります。
 *
 * @og.rev 4.0.0.0 (2005/08/31) 新規作成
 *
 * @version  0.9.0  2000/10/17
 * @author   Kazuhiko Hasegawa
 * @since    JDK1.1,
 */
public class TableFilter_INDEX_MYSQL extends TableFilter_INDEX {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.0.2.3 (2014/10/10)" ;

	/**
	 * 定義の最後の部分の処理を実行します。
	 *
	 * @og.rev 6.0.2.3 (2014/10/10) EXEC_END_TAG を追加。キャッシュします。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	定義の最後の部分
	 */
	@Override
	protected String makeEndLine( final int[] clmNo,final String[] data ) {
		return execEndTag ;
//		return isXml ? EXEC_END_TAG : ";" ;
	}

	/**
	 * インデックス削除の構文を、作成します。
	 *
	 * @og.rev 5.6.9.2 (2013/10/18) 新規作成
	 * @og.rev 6.0.2.3 (2014/10/10) EXEC_END_TAG を追加。キャッシュします。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	作成された１行分の文字列
	 */
	@Override
	protected String makeDropLine( final int[] clmNo,final String[] data ) {
		final String tableName = data[clmNo[TABLE_NAME]];
		final String indexName = data[clmNo[INDEX_NAME]];
	//	String idxtype   = data[clmNo[INDTYPE]];

		final StringBuilder buf = new StringBuilder( BUFFER_MIDDLE )
			.append( CR );		// 先頭に、改行を入れておきます。
		if( isXml ) { buf.append( EXEC_START_TAG ).append( CR ); }

		// 0:プライマリキー , 1:ユニークキー
	//	if( "0".equals( idxtype ) || "1".equals( idxtype ) ) {
			buf.append( "ALTER TABLE " ).append( tableName ).append( " DROP INDEX " )
				.append( indexName )
	//	}
		// 5.6.9.2 (2013/10/18) INDTYPE で、その他ではなく、2:通常 で判断する。
	//	else if( "2".equals( idxtype ) ) {	// 2:通常
	//		buf.append( "DROP INDEX " ).append( indexName ).append( " ON " ).append( tableName );
	//	}
	//  一連の処理で、makeLineList ですでにエラーが出ているハズなので、ここでは出しません。
	//	else {
	//	final String errMsg = "INDTYPE が、0,1,2 以外の値が使われています。INDTYPE=[" + idxtype + "]"
	//						+ " TABLE_NAME=[" + tableName + "] INDEX_NAME=[" + indexName + "]" ;
	//		System.out.println( errMsg );
	//	}

			// 6.0.2.3 (2014/10/10) EXEC_END_TAG の置き換え＋"/" の判定が必要。
			.append( execEndTag );
//		if( isXml )	{ buf.append( CR ).append( EXEC_END_TAG ); }
//		else		{ buf.append( ";" ); }

		return buf.toString();
	}

	/**
	 * インデックスを作成するための文字列を返します。
	 * 但し、唯一、MySQLの場合、500バイト以上のカラムについては、TEXTで定義しており、
	 * この場合、インデックス化するバイト数(最大255)を指定する必要があります。
	 * このケースに対応するため、カラム名とバイト数を元に判定し、部分インデックスを
	 * 作成するための文字列を作成します。
	 *
	 * @og.rev 5.1.1.2 (2009/12/10)
	 *
	 * @param	clm		カラム名
	 * @param	useLen	カラムのバイト数
	 *
	 * @return	インデックスカラムの文字列
	 */
	@Override
	protected String makeIndexClmStr( final String clm, final String useLen ) {
		int useLength = 0;
		if( useLen != null && useLen.length() > 0 ) {
//			useLength = Integer.valueOf( useLen );
			useLength = Integer.parseInt( useLen );			// 6.0.2.5 (2014/10/31) refactoring
		}
		return useLength > TableFilter_TABLE_MYSQL.CLM_MAX_SIZE ? clm + "(255)" : clm ;
	}
}
